/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License
 */

package com.android.phone.vvm.omtp.sync;

import android.content.Context;
import android.content.Intent;

import com.android.phone.vvm.omtp.scheduling.BaseTask;
import com.android.phone.vvm.omtp.scheduling.PostponePolicy;

/**
 * Upload task triggered by database changes. Will wait until the database has been stable for
 * {@link #POSTPONE_MILLIS} to execute.
 */
public class UploadTask extends BaseTask {

    private static final int POSTPONE_MILLIS = 5_000;

    public UploadTask() {
        super(TASK_UPLOAD);
        addPolicy(new PostponePolicy(POSTPONE_MILLIS));
    }

    public static void start(Context context) {
        Intent intent = BaseTask
                .createIntent(context, UploadTask.class, TaskId.SUB_ID_ANY);
        context.startService(intent);
    }

    @Override
    public void onExecuteInBackgroundThread() {
        OmtpVvmSyncService service = new OmtpVvmSyncService(getContext());
        service.sync(this, OmtpVvmSyncService.SYNC_UPLOAD_ONLY, null, null);
    }
}
